@@ -5,7 +5,7 @@
  
  @section LICENSE
  
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
@@ -165,7 +165,7 @@ class Clip(QueryObject):
         """ Get the translated display title of this item """
         path = self.data.get("reader", {}).get("path")
         folder_path, filename = os.path.split(path)
-        return os.path.splitext(filename)[0]
+        return filename
 
 class Transition(QueryObject):
     """ This class allows Transitions (i.e. timeline effects) to be queried, updated, and deleted from the project data. """
