@@ -30,6 +30,7 @@ import os
 import uuid
 import shutil
 import subprocess
+import sys
 import re
 import xml.dom.minidom as xml
 import functools
@@ -89,7 +90,7 @@ class BlenderListView(QListView):
 
         # Loop through params
         for param in animation.get("params",[]):
-            log.info(param["title"])
+            log.info('Using parameter %s: %s' % (param["name"], param["title"]))
 
             # Is Hidden Param?
             if param["name"] == "start_frame" or param["name"] == "end_frame":
@@ -197,8 +198,9 @@ class BlenderListView(QListView):
         self.init_slider_values()
 
     def spinner_value_changed(self, param, value):
+        log.info('Animation param being changed: %s' % param["name"])
         self.params[param["name"]] = value
-        log.info(value)
+        log.info('New value of param: %s' % value)
 
     def text_value_changed(self, widget, param, value=None):
         try:
@@ -207,29 +209,34 @@ class BlenderListView(QListView):
                 value = widget.toPlainText()
         except:
             pass
+        log.info('Animation param being changed: %s' % param["name"])
         self.params[param["name"]] = value.replace("\n", "\\n")
-        log.info(value)
+        log.info('New value of param: %s' % value)
 
     def dropdown_index_changed(self, widget, param, index):
+        log.info('Animation param being changed: %s' % param["name"])
         value = widget.itemData(index)
         self.params[param["name"]] = value
-        log.info(value)
+        log.info('New value of param: %s' % value)
 
     def color_button_clicked(self, widget, param, index):
+        # Get translation object
+        _ = get_app()._tr
+
         # Show color dialog
         log.info('Animation param being changed: %s' % param["name"])
         color_value = self.params[param["name"]]
         log.info('Value of param: %s' % color_value)
         currentColor = QColor("#FFFFFF")
         if len(color_value) == 3:
-            log.info('Using previous color: %s' % color_value)
             #currentColor = QColor(color_value[0], color_value[1], color_value[2])
             currentColor.setRgbF(color_value[0], color_value[1], color_value[2])
-        newColor = QColorDialog.getColor(currentColor)
+        newColor = QColorDialog.getColor(currentColor, self, _("Select a Color"),
+                                         QColorDialog.DontUseNativeDialog)
         if newColor.isValid():
             widget.setStyleSheet("background-color: {}".format(newColor.name()))
             self.params[param["name"]] = [newColor.redF(), newColor.greenF(), newColor.blueF()]
-            log.info(newColor.name())
+            log.info('New value of param: %s' % newColor.name())
 
     def generateUniqueFolder(self):
         """ Generate a new, unique folder name to contain Blender frames """
@@ -300,7 +307,7 @@ class BlenderListView(QListView):
 
         # Add file to project
         final_path = os.path.join(info.BLENDER_PATH, self.unique_folder_name, self.params["file_name"] + "%04d.png")
-        log.info(final_path)
+        log.info('Adding to project files: %s' % final_path)
 
         # Add to project files
         self.win.add_file(final_path)
@@ -608,10 +615,9 @@ class BlenderListView(QListView):
         self.setGridSize(QSize(102, 92))
         self.setViewMode(QListView.IconMode)
         self.setResizeMode(QListView.Adjust)
-        self.setUniformItemSizes(False)
+        self.setUniformItemSizes(True)
         self.setWordWrap(True)
         self.setTextElideMode(Qt.ElideRight)
-        self.setStyleSheet('QTreeView::item { padding-top: 2px; }')
 
         # Hook up button
         self.win.btnRefresh.clicked.connect(functools.partial(self.btnRefresh_clicked))
@@ -651,7 +657,7 @@ class BlenderListView(QListView):
 
     # Error from blender (with version number) (1003)
     def onBlenderVersionError(self, version):
-        log.info('onBlenderVersionError')
+        log.info('onBlenderVersionError: %s' % version)
         self.error_with_blender(version)
 
     # Error from blender (with no data) (1004)
@@ -661,12 +667,10 @@ class BlenderListView(QListView):
 
     # Signal when to update progress bar (1005)
     def onUpdateProgress(self, current_frame, current_part, max_parts):
-        # log.info ('onUpdateProgress')
         self.update_progress_bar(current_frame, current_part, max_parts)
 
     # Signal when to update preview image (1006)
     def onUpdateImage(self, image_path):
-        # log.info ('onUpdateImage: %s' % image_path)
         self.update_image(image_path)
 
     # Signal error from blender (with custom message) (1007)
@@ -715,11 +719,16 @@ class Worker(QObject):
         self.is_running = True
         _ = get_app()._tr
 
+        startupinfo = None
+        if sys.platform == 'win32':
+            startupinfo = subprocess.STARTUPINFO()
+            startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+
         try:
             # Shell the blender command to create the image sequence
             command_get_version = [self.blender_exec_path, '-v']
             command_render = [self.blender_exec_path, '-b', self.blend_file_path, '-P', self.target_script]
-            self.process = subprocess.Popen(command_get_version, stdout=subprocess.PIPE)
+            self.process = subprocess.Popen(command_get_version, stdout=subprocess.PIPE, stderr=subprocess.PIPE, startupinfo=startupinfo)
 
             # Check the version of Blender
             self.version = self.blender_version.findall(str(self.process.stdout.readline()))
@@ -739,7 +748,7 @@ class Worker(QObject):
                                                              command_render[3], command_render[4]))
 
             # Run real command to render Blender project
-            self.process = subprocess.Popen(command_render, stdout=subprocess.PIPE)
+            self.process = subprocess.Popen(command_render, stdout=subprocess.PIPE, stderr=subprocess.PIPE, startupinfo=startupinfo)
 
         except:
             # Error running command.  Most likely the blender executable path in the settings
@@ -771,11 +780,11 @@ class Worker(QObject):
 
             # Look for progress info in the Blender Output
             output_saved = self.blender_saved_expression.findall(str(line))
-            log.info("Image detected from blender regex: %s" % output_saved)
 
             # Does it have a match?
             if output_saved:
                 # Yes, we have a match
+                log.info("Image detected from blender regex: %s" % output_saved)
                 self.frame_detected = True
                 image_path = output_saved[0][0]
                 time_saved = output_saved[0][1]
