@@ -27,6 +27,7 @@
 
 import os
 from functools import partial
+from operator import itemgetter
 from PyQt5.QtCore import Qt, QRectF, QLocale, pyqtSignal, Qt, QObject, QTimer
 from PyQt5.QtGui import *
 from PyQt5.QtWidgets import QTableView, QAbstractItemView, QMenu, QSizePolicy, QHeaderView, QColorDialog, QItemDelegate, QStyle, QLabel, QPushButton, QHBoxLayout, QFrame
@@ -216,7 +217,7 @@ class PropertiesTableView(QTableView):
                         self.original_data = c.data
 
             # Calculate percentage value
-            if property_type in ["float", "int"]:
+            if property_type in ["float", "int"] and property_name != "Track":
                 min_max_range = float(property_max) - float(property_min)
 
                 # Determine if range is unreasonably long (such as position, start, end, etc.... which can be huge #'s)
@@ -272,6 +273,10 @@ class PropertiesTableView(QTableView):
 
     def doubleClickedCB(self, model_index):
         """Double click handler for the property table"""
+
+        # Get translation object
+        _ = get_app()._tr
+
         # Get data model and selection
         model = self.clip_properties_model.model
 
@@ -291,7 +296,8 @@ class PropertiesTableView(QTableView):
 
                 # Show color dialog
                 currentColor = QColor(red, green, blue)
-                newColor = QColorDialog.getColor(currentColor)
+                newColor = QColorDialog.getColor(currentColor, self, _("Select a Color"),
+                                                 QColorDialog.DontUseNativeDialog)
 
                 # Set the new color keyframe
                 self.clip_properties_model.color_update(self.selected_item, newColor)
@@ -381,6 +387,18 @@ class PropertiesTableView(QTableView):
                 # Add root transitions choice
                 self.choices.append({"name": _("Transitions"), "value": trans_choices, "selected": False})
 
+            # Handle reader type values
+            if property_name =="Track" and self.property_type == "int" and not self.choices:
+                # Populate all display track names
+                track_choices = []
+                all_tracks = get_app().project.get(["layers"])
+                display_count = len(all_tracks)
+                for track in reversed(sorted(all_tracks, key=itemgetter('number'))):
+                    # Append track choice
+                    track_name = track.get("label") or _("Track %s") % display_count
+                    self.choices.append({"name": track_name, "value": track.get("number"), "selected": False })
+                    display_count -= 1
+
             # Define bezier presets
             bezier_presets = [
                 (0.250, 0.100, 0.250, 1.000, _("Ease (Default)")),
@@ -737,4 +755,4 @@ class SelectionLabel(QFrame):
         self.setLayout(hbox)
 
         # Connect signals
-        get_app().window.propertyTableView.loadProperties.connect(self.select_item)
\ No newline at end of file
+        get_app().window.propertyTableView.loadProperties.connect(self.select_item)
